package com.ynet.life.filter;

import com.ynet.life.exception.TranFailException;
import java.io.IOException;
import java.util.Enumeration;
import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import org.apache.commons.lang.StringUtils;
import org.apache.oro.text.regex.Pattern;
import org.apache.oro.text.regex.Perl5Compiler;
import org.apache.oro.text.regex.Perl5Matcher;

/* loaded from: com_ynet_life_filter.jar:com/ynet/life/filter/SetCharacterEncodingFilter.class */
public class SetCharacterEncodingFilter implements Filter {
    private static TranFailException tfe = new TranFailException("EBLN1111", "提交数据中存在非法数据");
    private static Pattern invalidInputPattern;
    protected String encoding = null;
    protected FilterConfig filterConfig = null;
    protected boolean ignore = true;

    static {
        invalidInputPattern = null;
        try {
            invalidInputPattern = new Perl5Compiler().compile("<[\\s\\x00]*SCRIPT|</SCRIPT|SELECT\\s|INSERT\\s|DELETE\\s|UPDATE\\s|DROP\\s|<!--|-->|<FRAME|<IFRAME|<FRAMESET|<NOFRAME|<PLAINTEXT|<A\\s|<LINK|<MAP|<BGSOUND|<IMG|<FORM|<INPUT|<SELECT|<OPTION|<TEXTAREA|<APPLET|<OBJECT|<EMBED|<NOSCRIPT|<STYLE|ALERT\\((.)*\\)|ALERT[\\s\\x00]*\\>");
        } catch (Exception unused) {
            invalidInputPattern = null;
        }
    }

    public void destroy() {
        this.encoding = null;
        this.filterConfig = null;
    }

    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException {
        String encoding;
        if ((this.ignore || request.getCharacterEncoding() == null) && (encoding = selectEncoding(request)) != null) {
            String charset = request.getCharacterEncoding();
            if (charset != null) {
                if (charset.toUpperCase().indexOf("UTF-8") != -1) {
                    request.setCharacterEncoding("UTF-8");
                } else {
                    request.setCharacterEncoding(encoding);
                }
            } else {
                request.setCharacterEncoding(encoding);
            }
        }
        boolean invalidFlag = false;
        Perl5Matcher perl5Matcher = new Perl5Matcher();
        if (invalidInputPattern != null) {
            Enumeration<?> allParam = request.getParameterNames();
            while (true) {
                if (!allParam.hasMoreElements()) {
                    break;
                }
                String pName = (String) allParam.nextElement();
                String pValue = request.getParameter(pName);
                if (StringUtils.isNotEmpty(pValue) && perl5Matcher.contains(StringUtils.upperCase(pValue), invalidInputPattern)) {
                    request.setAttribute("dse_exception", tfe);
                    invalidFlag = true;
                    break;
                }
            }
        }
        if (invalidFlag) {
            response.setCharacterEncoding("UTF-8");
            StringBuffer sb = new StringBuffer("{");
            sb.append("\"ec\":\"EBLN1111").append("\",");
            sb.append("\"em\":\"提交数据中存在非法数据!").append("\"");
            sb.append("}");
            response.getOutputStream().write(sb.toString().getBytes("UTF-8"));
            return;
        }
        chain.doFilter(request, response);
    }

    public void init(FilterConfig filterConfig) throws ServletException {
        this.filterConfig = filterConfig;
        this.encoding = filterConfig.getInitParameter("encoding");
        String value = filterConfig.getInitParameter("ignore");
        if (value == null) {
            this.ignore = true;
            return;
        }
        if (value.equalsIgnoreCase("true")) {
            this.ignore = true;
        } else if (value.equalsIgnoreCase("yes")) {
            this.ignore = true;
        } else {
            this.ignore = false;
        }
    }

    protected String selectEncoding(ServletRequest request) {
        return this.encoding;
    }
}
